Changelog
=========

Version 0.1.4
-------------
- Cleared code to largely follow PEP 8 guidelines.

Version 0.1.3
-------------
- Changed installation directions in README.rst

Version 0.1.2
-------------
- Changed installation directions in README.rst

Version 0.1.1
-------------
- Project setup created by Pyscaffold.

- Generated documentation using Sphinx

Version 0.1
===========

- Initial release
